@@ -13,86 +13,54 @@ ModelAnalyticInfusionSteadyState = setClass(
   Class = "ModelAnalyticInfusionSteadyState",
   contains = "ModelAnalyticInfusion")
 
-setMethod(
-  f="initialize",
-  signature="ModelAnalyticInfusionSteadyState",
-  definition= function (.Object, name, description, equations, outcomes, parameters, modelError, initialConditions, odeSolverParameters)
-  {
-    if(!missing(name))
-    {
-      .Object@name = name
-    }
-    if(!missing(description))
-    {
-      .Object@description = description
-    }
-    if(!missing(equations))
-    {
-      .Object@equations = equations
-    }
-    if(!missing(outcomes))
-    {
-      .Object@outcomes = outcomes
-    }
-    if(!missing(parameters))
-    {
-      .Object@parameters = parameters
-    }
-    if(!missing(modelError))
-    {
-      .Object@modelError = modelError
-    }
-    if(!missing(initialConditions))
-    {
-      .Object@initialConditions = initialConditions
-    }
-    if(!missing( odeSolverParameters ) )
-    {
-      .Object@odeSolverParameters = odeSolverParameters
-    }
-    validObject(.Object)
-    return (.Object )
-  }
-)
-
-setMethod(
-  f="initialize",
-  signature="ModelAnalyticInfusionSteadyState",
-  definition= function (.Object, name, description, equations, outcomes, parameters, modelError)
-  {
-    if(!missing(name))
-    {
-      .Object@name = name
-    }
-    if(!missing(description))
-    {
-      .Object@description = description
-    }
-    if(!missing(equations))
-    {
-      .Object@equations = equations
-    }
-    if(!missing(outcomes))
-    {
-      .Object@outcomes = outcomes
-    }
-    if(!missing(parameters))
-    {
-      .Object@parameters = parameters
-    }
-    if(!missing(modelError))
-    {
-      .Object@modelError = modelError
-    }
-    validObject(.Object)
-    return (.Object )
-  }
+setMethod( f="initialize",
+           signature="ModelAnalyticInfusionSteadyState",
+           definition= function (.Object, name, description, equations, outcomes, parameters, modelError, initialConditions, odeSolverParameters)
+           {
+             if(!missing(name))
+             {
+               .Object@name = name
+             }
+             if(!missing(description))
+             {
+               .Object@description = description
+             }
+             if(!missing(equations))
+             {
+               .Object@equations = equations
+             }
+             if(!missing(outcomes))
+             {
+               .Object@outcomes = outcomes
+             }
+             if(!missing(parameters))
+             {
+               .Object@parameters = parameters
+             }
+             if(!missing(modelError))
+             {
+               .Object@modelError = modelError
+             }
+             if(!missing(initialConditions))
+             {
+               .Object@initialConditions = initialConditions
+             }
+             if(!missing( odeSolverParameters ) )
+             {
+               .Object@odeSolverParameters = odeSolverParameters
+             }
+             validObject(.Object)
+             return (.Object )
+           }
 )
 
 # ======================================================================================================
 # EvaluateModel
 # ======================================================================================================
 
+#' @rdname EvaluateModel
+#' @export
+
 setMethod(f="EvaluateModel",
           signature =  "ModelAnalyticInfusionSteadyState",
           definition = function( object, arm )
