@@ -37,36 +37,38 @@ ModelParameter = setClass(
 )
 
 # Initialize method
-setMethod(
-  f = "initialize",
-  signature = "ModelParameter",
-  definition = function( .Object, name, distribution, fixedMu, fixedOmega )
-  {
-    if(!missing(name))
-    {
-      .Object@name = name
-    }
-    if(!missing(distribution))
-    {
-      .Object@distribution = distribution
-    }
-    if(!missing(fixedMu))
-    {
-      .Object@fixedMu = fixedMu
-    }
-    if(!missing(fixedOmega))
-    {
-      .Object@fixedOmega = fixedOmega
-    }
-    validObject(.Object)
-    return(.Object)
-  }
+setMethod( f = "initialize",
+           signature = "ModelParameter",
+           definition = function( .Object, name, distribution, fixedMu, fixedOmega )
+           {
+             if(!missing(name))
+             {
+               .Object@name = name
+             }
+             if(!missing(distribution))
+             {
+               .Object@distribution = distribution
+             }
+             if(!missing(fixedMu))
+             {
+               .Object@fixedMu = fixedMu
+             }
+             if(!missing(fixedOmega))
+             {
+               .Object@fixedOmega = fixedOmega
+             }
+             validObject(.Object)
+             return(.Object)
+           }
 )
 
 # ======================================================================================================
 # getName
 # ======================================================================================================
 
+#' @rdname getName
+#' @export
+
 setMethod("getName",
           "ModelParameter",
           function(object)
@@ -75,13 +77,12 @@ setMethod("getName",
             return(name)
           })
 
-# ======================================================================================================
 #' Get the distribution.
 #'
 #' @name getDistribution
 #' @param object An object from the class \linkS4class{ModelParameter}.
 #' @return The parameter distribution.
-# ======================================================================================================
+#' @export
 
 setGeneric(
   "getDistribution",
@@ -89,6 +90,9 @@ setGeneric(
     standardGeneric("getDistribution")
   })
 
+#' @rdname getDistribution
+#' @export
+
 setMethod("getDistribution",
           "ModelParameter",
           function(object)
@@ -97,14 +101,13 @@ setMethod("getDistribution",
             return(distribution)
           })
 
-# ======================================================================================================
 #' Set the distribution.
 #'
 #' @name setDistribution
 #' @param object An object from the class \linkS4class{ModelParameter}.
 #' @param distribution An object from the class \linkS4class{Distribution}.
 #' @return The model parameter with the updated distribution.
-# ======================================================================================================
+#' @export
 
 setGeneric(
   "setDistribution",
@@ -112,6 +115,9 @@ setGeneric(
     standardGeneric("setDistribution")
   })
 
+#' @rdname setDistribution
+#' @export
+
 setMethod("setDistribution",
           "ModelParameter",
           function(object,distribution)
@@ -120,13 +126,12 @@ setMethod("setDistribution",
             return(object)
           })
 
-# ======================================================================================================
 #' Get the fixed effect.
 #'
 #' @name getFixedMu
 #' @param object An object from the class \linkS4class{ModelParameter}.
 #' @return A boolean giving the fixed mu.
-# ======================================================================================================
+#' @export
 
 setGeneric(
   "getFixedMu",
@@ -134,6 +139,9 @@ setGeneric(
     standardGeneric("getFixedMu")
   })
 
+#' @rdname getFixedMu
+#' @export
+
 setMethod("getFixedMu",
           signature("ModelParameter"),
           function(object)
@@ -141,14 +149,13 @@ setMethod("getFixedMu",
             return(object@fixedMu)
           })
 
-# ======================================================================================================
 #' Set the mu as fixed or not.
 #'
 #' @name setFixedMu
 #' @param object An object from the class \linkS4class{ModelParameter}.
 #' @param value A Boolean if fixed or not.
 #' @return The mode parameter with the the mu updated as fixed or not.
-# ======================================================================================================
+#' @export
 
 setGeneric(
   "setFixedMu",
@@ -156,6 +163,9 @@ setGeneric(
     standardGeneric("setFixedMu")
   })
 
+#' @rdname setFixedMu
+#' @export
+
 setMethod("setFixedMu",
           signature("ModelParameter"),
           function(object,value)
@@ -164,13 +174,12 @@ setMethod("setFixedMu",
             return(object)
           })
 
-# ======================================================================================================
 #' Get the fixed variance.
 #'
 #' @name getFixedOmega
 #' @param object An object from the class \linkS4class{ModelParameter}.
 #' @return A boolean giving the fixed omega.
-# ======================================================================================================
+#' @export
 
 setGeneric(
   "getFixedOmega",
@@ -178,6 +187,9 @@ setGeneric(
     standardGeneric("getFixedOmega")
   })
 
+#' @rdname getFixedOmega
+#' @export
+
 setMethod("getFixedOmega",
           signature("ModelParameter"),
           function(object)
@@ -185,14 +197,13 @@ setMethod("getFixedOmega",
             return(object@fixedOmega)
           })
 
-# ======================================================================================================
 #' Set the omega as fixed of not.
 #'
 #' @name setFixedOmega
 #' @param object An object from the class \linkS4class{ModelParameter}.
 #' @param value A Boolean fixed or not.
 #' @return The model parameter with the omega updated as fixed or not.
-# ======================================================================================================
+#' @export
 
 setGeneric(
   "setFixedOmega",
@@ -200,6 +211,9 @@ setGeneric(
     standardGeneric("setFixedOmega")
   })
 
+#' @rdname setFixedOmega
+#' @export
+
 setMethod("setFixedOmega",
           signature("ModelParameter"),
           function(object,value)
@@ -212,6 +226,9 @@ setMethod("setFixedOmega",
 # getMu
 # ======================================================================================================
 
+#' @rdname getMu
+#' @export
+
 setMethod("getMu",
           "ModelParameter",
           function(object)
@@ -226,6 +243,9 @@ setMethod("getMu",
 # setMu
 # ======================================================================================================
 
+#' @rdname setMu
+#' @export
+
 setMethod("setMu",
           "ModelParameter",
           function(object,value)
@@ -240,6 +260,9 @@ setMethod("setMu",
 # getOmega
 # ======================================================================================================
 
+#' @rdname getOmega
+#' @export
+
 setMethod("getOmega",
           "ModelParameter",
           function(object)
@@ -254,6 +277,9 @@ setMethod("getOmega",
 # setOmega
 # ======================================================================================================
 
+#' @rdname setOmega
+#' @export
+
 setMethod("setOmega",
           "ModelParameter",
           function(object,value)
